@@ -1,6 +1,8 @@
-from oct_converter.image_types import OCTVolumeWithMetaData, FundusImageWithMetaData
 from pathlib import Path
 
+from oct_converter.image_types import OCTVolumeWithMetaData
+
+
 class Dicom(object):
     def __init__(self, filepath):
         self.filepath = Path(filepath)
@@ -8,12 +10,13 @@ class Dicom(object):
             raise FileNotFoundError(self.filepath)
 
     def read_oct_volume(self):
-        """ Reads OCT data.
+        """Reads OCT data.
 
-            Returns:
-                obj:OCTVolumeWithMetaData
+        Returns:
+            obj:OCTVolumeWithMetaData
         """
         import pydicom
+
         dicom_data = pydicom.dcmread(self.filepath)
         pixel_data = dicom_data.pixel_array
         oct_volume = OCTVolumeWithMetaData(volume=pixel_data)
